using System;
using System.Collections.Generic;
using System.Text;
using MaxiBioInterfaceLibrary;

namespace MaxiBioClassLibrary
{
    class Biograf : IBiograf
    {
        #region felter for selve Biograf klassen 
        private string biografnavn;
        #endregion
        
        #region properties og metoder selve MaxiBio
        public Biograf(string initBiografnavn)
        {
            this.biografnavn = initBiografnavn;
        }
        public string Biografnavn
        {
            get { return this.biografnavn; }
            set { this.biografnavn = value; }
        }
        public override string ToString()
        {
            return this.biografnavn;
        }
        #endregion

        #region data og metoder for Biografens's tilhrende Biografsale

        private List<IBiografsal> biografsalListe = new List<IBiografsal>();
        
        // Opretter ny sal i biografen:
        public IBiografsal OpretBiografsal(string navn, bool thx, int antalPladser)
        {
            IBiografsal nyBiografsal = new Biografsal(navn, thx, antalPladser);
            this.biografsalListe.Add(nyBiografsal);
            return nyBiografsal;
        }
        
        // Find film efter titel:
        public IBiografsal FindBiografsal(string sgeNavn)
        {
            foreach (IBiografsal enBiografsal in this.biografsalListe)
            {
                if (enBiografsal.Navn.ToLower().Contains(sgeNavn.ToLower()))
                {
                    return enBiografsal;
                }
            }
            return null;
        }

        public IBiografsal[] HentAlleBiografsale()
        {
            return this.biografsalListe.ToArray();
        }

        #endregion

        #region afledte metoder vedrrende Forestillinger
        // Biograf klassen kan via sine Biografsale vre expert p tvrs af disse

        // Find foretillinger efter dato 
        public IForestilling[] FindForestillinger(int sgeDato)
        {
            List<IForestilling> fundneForestillinger = new List<IForestilling>();
            foreach (IBiografsal enBiografsal in this.biografsalListe)
            {
                IForestilling[] salensForestiller = 
                    enBiografsal.FindForestillinger(sgeDato);
                
                fundneForestillinger.AddRange(salensForestiller);
                // AddRange lber samlingen igennem og udfrer add p hvert element
            }
            return fundneForestillinger.ToArray();
        }

        // Find foretillinger i periode 
        public IForestilling[] FindForestillinger(int startDato, int slutDato)
        {
            List<IForestilling> fundneForestillinger = new List<IForestilling>();
            foreach (IBiografsal enBiografsal in this.biografsalListe)
            {
                IForestilling[] salensForestiller =
                    enBiografsal.FindForestillinger(startDato, slutDato);

                fundneForestillinger.AddRange(salensForestiller);
                // AddRange lber samlingen igennem og udfrer add p hvert element
            }
            return fundneForestillinger.ToArray();
        }

        public IForestilling[] HentAlleForestillinger()
        {
            List<IForestilling> fundneForestillinger = new List<IForestilling>();
            foreach (IBiografsal enBiografsal in this.biografsalListe)
            {
                IForestilling[] salensForestiller =
                    enBiografsal.HentAlleForestillinger();

                fundneForestillinger.AddRange(salensForestiller);
                // AddRange lber samlingen igennem og udfrer add p hvert element
            }
            return fundneForestillinger.ToArray();
        }

        #endregion
    }
}
