using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using MaxiBioInterfaceLibrary;
using MaxiBioClassLibrary;

namespace MaxiBioWindowsApplication
{
    public partial class FilmForm : Form
    {
        private IMaxiBio aktuelMaxibio;
        private IFilm aktuelFilm;

        public FilmForm(IMaxiBio initMaxibio)
        {
            InitializeComponent();

            // opret test objekt
            //this.aktuelMaxibio = new MaxiBio();

            this.aktuelMaxibio = initMaxibio;
            fyldFilmListBox();
        }

        public FilmForm()
        {
            InitializeComponent();

            // opret test objekt
            //this.aktuelMaxibio = new MaxiBio();
            // Da MaxiBioFasade "holder" p MaxiBio objektet kan vi f fat i det
            // selv her fra formen uden at det overfres til os
            this.aktuelMaxibio = MaxiBioFasade.GetMaxiBioObjektet();
            fyldFilmListBox();
        }

        private void fyldFilmListBox()
        {
            // frst hentes data
            IFilm[] alleFilm = this.aktuelMaxibio.HentAlleFilm();
            // s indsttes i listboxen, der frst "renses" for evt. gamle data
            this.lbxFilm.Items.Clear();
            this.lbxFilm.Items.AddRange(alleFilm);
        }

        private void visFilmData()
        {
            if (this.aktuelFilm == null) return;

            this.txtFilmTitel.Text = this.aktuelFilm.Titel;
            this.txtFilmGenre.Text = this.aktuelFilm.Genre;
            this.chkFilmThx.Checked = this.aktuelFilm.Thx;
            this.txtFilmVarighed.Text = this.aktuelFilm.Varighed.ToString();
            this.txtFilmSkuespillere.Text = this.aktuelFilm.Skuespillere;
            this.txtFilmResume.Text = this.aktuelFilm.Resume;
        }

        private void btnOpretFilm_Click(object sender, EventArgs e)
        {
            string titel = this.txtFilmTitel.Text;
            string genre = this.txtFilmGenre.Text;
            bool thx = this.chkFilmThx.Checked;
            int varighed = int.Parse(this.txtFilmVarighed.Text);
            string skuespillere = this.txtFilmSkuespillere.Text;
            string resume = this.txtFilmResume.Text;
            this.aktuelFilm = this.aktuelMaxibio.OpretFilm(titel, genre, skuespillere, resume, varighed, thx);
        }

        private void btnFindFilm_Click(object sender, EventArgs e)
        {
            string titel = this.txtFilmTitel.Text;
            this.aktuelFilm = this.aktuelMaxibio.FindFilm(titel);
            if (this.aktuelFilm == null)
                MessageBox.Show("Film findes ikke");
            else
                visFilmData();
        }

        private void btnRetFilm_Click(object sender, EventArgs e)
        {
            if (this.aktuelFilm == null)
            {
                MessageBox.Show("Du skal frst finde en film");
            }
            else
            {
                string titel = this.txtFilmTitel.Text;
                string genre = this.txtFilmGenre.Text;
                bool thx = this.chkFilmThx.Checked;
                int varighed = int.Parse(this.txtFilmVarighed.Text);
                string skuespillere = this.txtFilmSkuespillere.Text;
                string resume = this.txtFilmResume.Text;
                this.aktuelFilm.Titel = titel;
                this.aktuelFilm.Genre = genre;
                this.aktuelFilm.Thx = thx;
                this.aktuelFilm.Varighed = varighed;
                this.aktuelFilm.Skuespillere = skuespillere;
                this.aktuelFilm.Resume = resume;
            }

        }

        private void lbxFilm_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.aktuelFilm = this.lbxFilm.SelectedItem as IFilm;
            visFilmData();
        }
    }
}