using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using MaxiBioInterfaceLibrary;
using MaxiBioClassLibrary;

namespace MaxiBioWindowsApplication
{
    public partial class ForestillingForm : Form
    {
        private IBiografsal aktuelBiografsal;
        private IForestilling aktuelForestilling;

        public ForestillingForm(IBiografsal initBiografsal, IForestilling initForestilling)
        {
            InitializeComponent();

            // opret test objekt
            //this.aktuelBiografsal = new Biografsal("Test sal", true, 100);
            this.aktuelBiografsal = initBiografsal;
            this.aktuelForestilling = initForestilling;
            this.txtSalnavn.Text = this.aktuelBiografsal.Navn;
            if (this.aktuelForestilling != null)
            {
                this.txtDato.Text = this.aktuelForestilling.Dato.ToString();
                this.txtTidspunkt.Text = this.aktuelForestilling.Tidspunkt.ToString();
                visDataForTilknyttetFilm();
            }
            fyldFilmListBox();
        }

        private void visDataForTilknyttetFilm()
        {
            IFilm tilknyttetFilm = this.aktuelForestilling.HentTillnyttetFilm();
            if (tilknyttetFilm != null)
            {
                this.txtFilmTitel.Text = tilknyttetFilm.Titel;
            }
            else
            {
                this.txtFilmTitel.Text = "Ingen film tilknyttet";
            }
        }

        private void fyldFilmListBox()
        {
            IMaxiBio aktueltMaxiBio = MaxiBioFasade.GetMaxiBioObjektet();
            IFilm[] alleFilm = aktueltMaxiBio.HentAlleFilm();
            this.lbxFilm.Items.Clear();
            this.lbxFilm.Items.AddRange(alleFilm);
        }

        private void btnOpretForestilling_Click(object sender, EventArgs e)
        {
            int dato = int.Parse(this.txtDato.Text);
            int tidspunkt = int.Parse(this.txtTidspunkt.Text);
            this.aktuelForestilling = this.aktuelBiografsal.OpretForestilling(dato, tidspunkt);
            visDataForTilknyttetFilm();
        }

        private void btnFindForestilling_Click(object sender, EventArgs e)
        {
            int dato = int.Parse(this.txtDato.Text);
            int tidspunkt = int.Parse(this.txtTidspunkt.Text);
            this.aktuelForestilling = this.aktuelBiografsal.FindForestilling(dato, tidspunkt);
            if (this.aktuelForestilling == null)
                MessageBox.Show("Forestilling findes ikke");
            else
                visDataForTilknyttetFilm();
        }

        private void btnRetForestilling_Click(object sender, EventArgs e)
        {
            if (this.aktuelForestilling == null)
            {
                MessageBox.Show("Du skal frst finde en forestilling");
            }
            else
            {
                int dato = int.Parse(this.txtDato.Text);
                int tidspunkt = int.Parse(this.txtTidspunkt.Text);
                this.aktuelForestilling.Dato = dato;
                this.aktuelForestilling.Tidspunkt = tidspunkt;
            }
        }

        private void btnTilknytFilm_Click(object sender, EventArgs e)
        {
            IFilm valgtFilm = this.lbxFilm.SelectedItem as IFilm;
            if (valgtFilm == null)
                MessageBox.Show("Der skal vlges en film");
            else
            {
                this.aktuelForestilling.TilknytFilm(valgtFilm);
                visDataForTilknyttetFilm();
            }
               
        }
    }
}