using System;
using System.Collections.Generic;
using System.Text;
using MaxiBioInterfaceLibrary;

namespace MaxiBioClassLibrary
{
    class Biografsal : IBiografsal
    {
        #region felter for selve biografsal klassen 
        private string navn;
        private bool thx;
        private int antalPladser;
        #endregion
        
        #region properties og metoder selve Biografsal klassen
        public Biografsal(string initNavn, bool initThx, int initAntalPladser)
        {
            this.navn = initNavn;
            this.thx = initThx;
            this.antalPladser = initAntalPladser;
        }
        public string Navn
        {
            get { return this.navn; }
            set { this.navn = value; }
        }
        public bool Thx
        {
            get { return this.thx; }
            set { this.thx = value; }
        }
        public int AntalPladser
        {
            get { return this.antalPladser ; }
            set { this.antalPladser = value; }
        }
        public override string ToString()
        {
            if (this.thx)
                return this.navn+"; thx; "+this.antalPladser;
            return this.navn + ";" + this.antalPladser;
        }
        #endregion

        #region data og metoder for Biografsalen's tilhrende Forestillinger

        private List<IForestilling> forestillingListe = new List<IForestilling>();

        // Opretter ny forestilling i biografsalen
        public IForestilling OpretForestilling(int dato, int tidspunkt)
        {
            IForestilling nyForestilling = new Forestilling(dato, tidspunkt);
            this.forestillingListe.Add(nyForestilling);
            return nyForestilling;
        }

        // Opretter ny forestilling i biografsalen ned tilknyttet film
        public IForestilling OpretForestilling(int dato, int tidspunkt, IFilm enFilm)
        {
            IForestilling nyForestilling = new Forestilling(dato, tidspunkt, enFilm);
            this.forestillingListe.Add(nyForestilling);
            return nyForestilling;
        }

        // Find foretilling efter dato og tidspunkt
        public IForestilling FindForestilling(int sgeDato, int sgeTidspunkt)
        {
            foreach (IForestilling enForestilling in this.forestillingListe)
            {
                if (enForestilling.Dato == sgeDato && enForestilling.Tidspunkt == sgeTidspunkt)
                {
                    return enForestilling;
                }
            }
            return null;
        }

        // Find foretillinger efter dato 
        public IForestilling[] FindForestillinger(int sgeDato)
        {
            List<IForestilling> fundneForestillinger = new List<IForestilling>();
            foreach (IForestilling enForestilling in this.forestillingListe)
            {
                if (enForestilling.Dato == sgeDato)
                {
                    fundneForestillinger.Add(enForestilling);
                }
            }
            return fundneForestillinger.ToArray();
        }

        // Find foretillinger i periode 
        public IForestilling[] FindForestillinger(int startDato, int slutDato)
        {
            List<IForestilling> fundneForestillinger = new List<IForestilling>();
            foreach (IForestilling enForestilling in this.forestillingListe)
            {
                if (startDato <= enForestilling.Dato && enForestilling.Dato <= slutDato)
                {
                    fundneForestillinger.Add(enForestilling);
                }
            }
            return fundneForestillinger.ToArray();
        }

        public IForestilling[] HentAlleForestillinger()
        {
            return this.forestillingListe.ToArray();
        }

        #endregion
    }
}
