using System;
using System.Collections.Generic;
using System.Text;
using MaxiBioInterfaceLibrary;

namespace MaxiBioClassLibrary
{
    class MaxiBio : IMaxiBio
    {
        #region felter for selve MaxiBio klassen
        private string firmanavn;
        #endregion
        
        #region properties og metoder selve MaxiBio klassen
        public MaxiBio()
        {
            this.firmanavn = "MaxiBio";
        }
        public string Firmanavn
        {
            get { return this.firmanavn; }
            set { this.firmanavn = value; }
        }
        public override string ToString()
        {
            return this.firmanavn;
        }
        #endregion

        #region data og metoder for MaxiBio's tilhrende film

        private List<IFilm> filmListe = new List<IFilm>();
        
        // Opretter ny film i filmsamlingen:
        public IFilm OpretFilm(string titel, string genre, string skuespillere, string resume, int varighed, bool thx)
        {
            IFilm nyFilm = new Film(titel, genre, skuespillere, resume, varighed, thx);
            this.filmListe.Add(nyFilm);
            return nyFilm;
        }
        
        // Find film efter titel:
        public IFilm FindFilm(string sgeTitel)
        {
            foreach (IFilm enFilm in this.filmListe )
            {
                if (enFilm.Titel.ToLower().Contains(sgeTitel.ToLower()))
                {
                    return enFilm;
                }
            }
            return null;
        }
        
        public IFilm[] HentAlleFilm()
        {
            return this.filmListe.ToArray();
        }

        #endregion
        
        #region data og metoder for MaxiBio's tilhrende Biografer

        private List<IBiograf> biografListe = new List<IBiograf>();

        // Opretter ny biograf
        public IBiograf OpretBiograf(string biografnavn)
        {
            IBiograf nyBiograf = new Biograf(biografnavn);
            this.biografListe.Add(nyBiograf);
            return nyBiograf;
        }

        // Find biograf p navn
        public IBiograf FindBiograf(string sgeNavn)
        {
            foreach (IBiograf enBiograf in this.biografListe)
            {
                if (enBiograf.Biografnavn.ToLower().Contains(sgeNavn.ToLower()))
                {
                    return enBiograf;
                }
            }
            return null;
        }

        public IBiograf[] HentAlleBiografer()
        {
            return this.biografListe.ToArray();
        }

        #endregion

        #region afledte metoder vedrrende Forestillinger
        // Biograf klassen kan via sine Biografer vre expert p tvrs af disse

        // Find foretillinger efter dato 
        public IForestilling[] FindForestillinger(int sgeDato)
        {
            List<IForestilling> fundneForestillinger = new List<IForestilling>();
            foreach (IBiograf enBiograf in this.biografListe)
            {
                IForestilling[] biografensForestiller =
                    enBiograf.FindForestillinger(sgeDato);

                fundneForestillinger.AddRange(biografensForestiller);
                // AddRange lber samlingen igennem og udfrer add p hvert element
            }
            return fundneForestillinger.ToArray();
        }

        // Find foretillinger i periode 
        public IForestilling[] FindForestillinger(int startDato, int slutDato)
        {
            List<IForestilling> fundneForestillinger = new List<IForestilling>();
            foreach (IBiograf enBiograf in this.biografListe)
            {
                IForestilling[] biografensForestiller =
                    enBiograf.FindForestillinger(startDato, slutDato);

                fundneForestillinger.AddRange(biografensForestiller);
                // AddRange lber samlingen igennem og udfrer add p hvert element
            }
            return fundneForestillinger.ToArray();
        }

        public IForestilling[] HentAlleForestillinger()
        {
            List<IForestilling> fundneForestillinger = new List<IForestilling>();
            foreach (IBiograf enBiograf in this.biografListe)
            {
                IForestilling[] biografensForestiller =
                    enBiograf.HentAlleForestillinger();

                fundneForestillinger.AddRange(biografensForestiller);
                // AddRange lber samlingen igennem og udfrer add p hvert element
            }
            return fundneForestillinger.ToArray();
        }

        #endregion

    }
}
